
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007000
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Alders
Alders'
Eilam
Eilam's
MaxMind
MaxMind's
Oschwald
Oschwald's
Rolsky
Rolsky's
AKA
AVS
BAID
CORRELATIONID
INSTANTIATION
Mojo
ORIGID
PNREF
PPA
Payflow
RESPMSG
SECURETOKEN
SECURETOKENID
TRANSTIME
UserAgent
app
apps
baid
correlationid
iframe
param
params
payflow
plack
pnref
ppref
sandbox
settable
transtime
ua
website
Olaf
olaf
Inc
Dave
drolsky
Greg
goschwald
Mark
Fowler
mark
oalders
lib
WebService
PayPal
PaymentsAdvanced
Error
Authentication
Generic
HTTP
HostedForm
IPVerification
Role
HasHTTPResponse
Mocker
Helper
PayflowLink
PayflowPro
SilentPOST
Response
Authorization
CreditCard
Capture
Credit
FromHTTP
FromRedirect
FromSilentPOST
Inquiry
Sale
SecureToken
Void
ClassFor
HasCreditCard
HasMessage
HasParams
HasPayPal
HasTender
HasTokens
HasTransactionTime
HasUA
